Learn R Programming

sspm (version 1.1.0)

spm_as_boundary: Create a sspm_boundary object

Description

Create a sspm_boundary object. A boundary object serves as a basis to encode the spatial extent of the model.

Usage

spm_as_boundary(
  boundaries,
  boundary,
  patches = NULL,
  points = NULL,
  boundary_area = NULL,
  patch_area = NULL
)

# S4 method for missing,ANY,ANY,ANY spm_as_boundary( boundaries, boundary, patches = NULL, points = NULL, boundary_area = NULL, patch_area = NULL )

# S4 method for ANY,missing,ANY,ANY spm_as_boundary( boundaries, boundary, patches = NULL, points = NULL, boundary_area = NULL, patch_area = NULL )

# S4 method for sf,character,missing,missing spm_as_boundary( boundaries, boundary, patches = NULL, points = NULL, boundary_area = NULL, patch_area = NULL )

# S4 method for sf,character,ANY,ANY spm_as_boundary( boundaries, boundary, patches = NULL, points = NULL, boundary_area = NULL, patch_area = NULL )

Value

An object of class sspm_boundary or sspm_discrete_boundary.

Arguments

boundaries

[sf] The sf object to cast.

boundary

[character] The column that contains the possible subdivisions of the boundaries.

patches

[sf] Patches resulting from discretization.

points

[sf] Sample points used for discretization.

boundary_area

[character] The column that contains the area of the subdivisions (optional).

patch_area

[character] The column that contains the area of the patches (optional).

Examples

Run this code
sfa_boundaries
bounds <- spm_as_boundary(boundaries = sfa_boundaries,
                          boundary = "sfa")
plot(bounds)

Run the code above in your browser using DataLab