Learn R Programming

sspm (version 1.1.0)

spm_boundaries,sspm_boundary-method: Accessing OR replacing sspm_boundary model elements

Description

All methods described here allow to access the elements of contained in objects of class sspm_boundary.

Usage

# S4 method for sspm_boundary
spm_boundaries(sspm_object)

# S4 method for sspm_boundary spm_boundaries(object) <- value

spm_discret_method(sspm_object)

# S4 method for sspm_discrete_boundary spm_discret_method(sspm_object)

spm_discret_method(object) <- value

# S4 method for sspm_discrete_boundary spm_discret_method(object) <- value

spm_patches(sspm_object)

# S4 method for sspm_discrete_boundary spm_patches(sspm_object)

spm_patches(object) <- value

# S4 method for sspm_discrete_boundary spm_patches(object) <- value

spm_points(sspm_object)

# S4 method for sspm_discrete_boundary spm_points(sspm_object)

spm_points(object) <- value

# S4 method for sspm_discrete_boundary spm_points(object) <- value

spm_boundary(sspm_object)

# S4 method for sspm_boundary spm_boundary(sspm_object)

spm_boundary(object) <- value

# S4 method for sspm_boundary spm_boundary(object) <- value

spm_boundary_area(sspm_object)

# S4 method for sspm_boundary spm_boundary_area(sspm_object)

spm_boundary_area(object) <- value

# S4 method for sspm_boundary spm_boundary_area(object) <- value

spm_patches_area(sspm_object)

# S4 method for sspm_discrete_boundary spm_patches_area(sspm_object)

spm_patches_area(object) <- value

# S4 method for sspm_discrete_boundary spm_patches_area(object) <- value

Value

The object in the required slot.

Arguments

sspm_object

[sspm_boundary] An object of class sspm_boundary.

object

[sspm_boundary] An object of class sspm_boundary.

value

typically an array-like R object of a similar class as x.

Examples

Run this code
data(borealis_simulated, package = "sspm")
biomass_dataset <- spm_as_dataset(data.frame(borealis_simulated), name = "borealis",
                                  density = "weight_per_km2",
                                  time = "year_f",
                                  coords = c('lon_dec','lat_dec'),
                                  uniqueID = "uniqueID")
spm_boundaries(biomass_dataset)

Run the code above in your browser using DataLab