spm_lag: Create lagged columns in a sspm smoothed data slot
Description
This function is a wrapper around lag (note that not all
arguments are supported). The default value for the lag is the mean of the
series.
Usage
spm_lag(sspm_object, vars, n = 1, default = "mean", ...)
# S4 method for sspm
spm_lag(sspm_object, vars, n = 1, default = "mean", ...)
# S4 method for sspm_fit
spm_lag(sspm_object, vars, n = 1, default = "mean", ...)
Value
Updated sspm_object.
Arguments
sspm_object
[sspm_dataset] An object of class
sspm_dataset.
vars
[character] Names of the variables to lag.
n
Positive integer of length 1, giving the number of positions to
lag or lead by
default
The value used to pad x back to its original size after the
lag or lead has been applied. The default, NULL, pads with a missing
value. If supplied, this must be a vector with size 1, which will be cast
to the type of x.
...
a list of variables that are the covariates that this
smooth is a function of. Transformations whose form depends on
the values of the data are best avoided here: e.g. s(log(x))
is fine, but s(I(x/sd(x))) is not (see predict.gam).