Learn R Programming

sspm (version 1.1.0)

spm_unique_ID,sspm_fit-method: Accessing OR replacing sspm_fit model elements

Description

All methods described here allow to access the elements of contained in objects of class sspm_fit.

Usage

# S4 method for sspm_fit
spm_unique_ID(sspm_object)

# S4 method for sspm_fit spm_unique_ID(object) <- value

# S4 method for sspm_fit spm_time(sspm_object)

# S4 method for sspm_fit spm_time(object) <- value

# S4 method for sspm_fit spm_formulas(sspm_object)

# S4 method for sspm_fit spm_formulas(object) <- value

# S4 method for sspm_fit spm_smoothed_data(sspm_object)

# S4 method for sspm_fit spm_smoothed_data(object) <- value

spm_get_fit(sspm_object)

# S4 method for sspm_fit spm_get_fit(sspm_object)

spm_get_fit(object) <- value

# S4 method for sspm_fit spm_get_fit(object) <- value

# S4 method for sspm_fit spm_boundaries(sspm_object)

# S4 method for sspm_fit spm_boundaries(object) <- value

# S4 method for sspm_fit spm_boundary(sspm_object)

# S4 method for sspm_fit spm_boundary(object) <- value

Value

The object in the required slot.

Arguments

sspm_object

[sspm_fit] An object of class sspm_fit.

object

[sspm_fit] An object of class sspm_fit.

value

typically an array-like R object of a similar class as x.

Examples

Run this code
data(borealis_simulated, package = "sspm")
biomass_dataset <- spm_as_dataset(data.frame(borealis_simulated), name = "borealis",
                                  density = "weight_per_km2",
                                  time = "year_f",
                                  coords = c('lon_dec','lat_dec'),
                                  uniqueID = "uniqueID")
spm_formulas(biomass_dataset)

Run the code above in your browser using DataLab