Generates delaunay triangles with ct_triangulate().
triangulate_delaunay(
boundaries,
with = NULL,
boundary = "sfa",
sample_surface = FALSE,
sample_points = FALSE,
nb_samples = NULL,
min_size = 1000,
seed = 1,
...
)A named list with three elements (each an sf object):
* patches, the voronoi polygons generated
* points, the points used for the tessellation.
[sf] The boundaries to be used.
[sf] A set of data points to use for voronoisation.
[character] The column in boundaries that is to
be used for the stratified sampling.
[logical] Whether to sample the surfaces in
boundaries, Default to FALSE.
[logical] Whether to sample points from with or
to take all points in with. Default to TRUE.
[named character vector] The number of samples to draw
by boundary polygons (must bear the levels of boundary as names
or be a single value to be applied to each level).
[numeric] The minimum size for a triangle above which it will be merged (in km2).
[numeric] Passed onto set.seed(),
important for reproducibility of sampling.
Arguments passed on to RTriangle::triangulate
pPlanar straight line graph object; see
pslg.
aMaximum triangle area. If specified, triangles cannot be larger than this area.
qMinimum triangle angle in degrees.
YIf TRUE prohibits the insertion of Steiner points
on the mesh boundary.
jIf TRUE jettisons vertices that are not part of
the final triangulation from the output.
DIf TRUE produce a conforming Delaunay
triangulation. This ensures that all the triangles in the mesh
are truly Delaunay, and not merely constrained Delaunay. This
option invokes Ruppert's original algorithm, which splits every
subsegment whose diametral circle is encroached. It usually
increases the number of vertices and triangles.
SSpecifies the maximum number of added Steiner points. If
set to Inf, there is no limit on the number of Steine
points added - but this can lead to huge amounts of memory being
allocated.
VVerbosity level. Specify higher values for more detailed information about what the Triangle library is doing.
QIf TRUE suppresses all explanation of what the
Triangle library is doing, unless an error occurs.
data(borealis_simulated, package = "sspm")
data(sfa_boundaries, package = "sspm")
triangulate_delaunay(sfa_boundaries, with = borealis, sample_surface = TRUE,
boundary = "sfa", nb_samples = 10)
Run the code above in your browser using DataLab